searchData={"items":[{"type":"module","title":"ZenRows","doc":"A client library for interacting with the ZenRows API.\n\nThe `ZenRows` module provides a simple and convenient way to send HTTP requests to the ZenRows API.\nIt supports both GET and POST requests and allows customization of request options.","ref":"ZenRows.html"},{"type":"module","title":"Configuration - ZenRows","doc":"The `ZenRows` module can be configured using the application environment. The following options are available:\n\n- `:api_key` (required): The API key for authentication with the ZenRows API.\n- `:retries` (optional): The number of times to retry failed requests. Default is 3.\n- `:timeout` (optional): The request timeout in milliseconds. Default is 30000.\n\nExample configuration:\n\n    config :zenrows,\n      api_key: \"YOUR_API_KEY\",\n      retries: 3,\n      timeout: 30000","ref":"ZenRows.html#module-configuration"},{"type":"module","title":"Usage - ZenRows","doc":"To make a GET request:\n\n    ZenRows.get(\"https://example.com\", headers: %{\"Authorization\" => \"Bearer token\"}, config: %ZenRows.Config{js_render: true})\n\nTo make a POST request:\n\n    ZenRows.post(\"https://example.com\", data: %{key: \"value\"}, headers: %{\"Authorization\" => \"Bearer token\"})","ref":"ZenRows.html#module-usage"},{"type":"module","title":"Options - ZenRows","doc":"The following options can be passed to `get/2` and `post/2`:\n\n- `:headers` (optional): A map of additional headers to include in the request. Default is an empty map.\n- `:config` (optional): A `ZenRows.Config` struct specifying the configuration options for the request. Default is an empty struct.\n- `:data` (optional): A map of data to be sent as the request body in a POST request. Default is an empty map.\n- `:retries` (optional): The number of times to retry failed requests. Overrides the application environment configuration.\n- `:timeout` (optional): The request timeout in milliseconds. Default is 30000.","ref":"ZenRows.html#module-options"},{"type":"function","title":"ZenRows.get/2","doc":"Sends a GET request to the specified URL with the given options.\n\nReturns a `Tesla.Env` struct representing the response.","ref":"ZenRows.html#get/2"},{"type":"function","title":"ZenRows.post/2","doc":"Sends a POST request to the specified URL with the given options.\n\nReturns a `Tesla.Env` struct representing the response.","ref":"ZenRows.html#post/2"},{"type":"type","title":"ZenRows.option/0","doc":"","ref":"ZenRows.html#t:option/0"},{"type":"type","title":"ZenRows.options/0","doc":"","ref":"ZenRows.html#t:options/0"},{"type":"module","title":"ZenRows.Config","doc":"Represents the configuration options for a ZenRows API request.\n\nThe `ZenRows.Config` struct defines the available parameters that can be passed to the ZenRows API.\nThese parameters allow customization of the scraping behavior and enable additional features.\n\nRefer to the [ZenRows API Documentation](https://docs.zenrows.com/api-reference) for more details on each parameter.","ref":"ZenRows.Config.html"},{"type":"module","title":"Parameters - ZenRows.Config","doc":"- `js_render` (optional): Render the JavaScript on the page with a headless browser. Default is `false`. Enabling this option consumes 5 credits per request.\n- `premium_proxy` (optional): Use premium proxies to make the request harder to detect. Default is `false`. Enabling this option consumes 10-25 credits per request.\n- `proxy_country` (optional): Geolocation of the IP used to make the request. Only applicable when using premium proxies. Example: \"us\".\n- `session_id` (optional): Send a session ID number to use the same IP for each API request for up to 10 minutes.\n- `device` (optional): Use either desktop or mobile user agents in the headers. Default is `\"desktop\"`.\n- `original_status` (optional): Returns the status code provided by the website. Default is `false`.\n- `wait_for` (optional): Wait for a given CSS selector to load in the DOM before returning the content.\n- `wait` (optional): Wait a fixed amount of time (in milliseconds) before returning the content. Default is `0`.\n- `block_resources` (optional): Block specific resources from loading using this parameter.\n- `json_response` (optional): Get content in JSON format, including XHR or Fetch requests. Default is `false`.\n- `window_width` (optional): Set the browser's window width. Default is `1920`.\n- `window_height` (optional): Set the browser's window height. Default is `1080`.\n- `css_extractor` (optional): Define CSS selectors to extract data from the HTML. Expects a JSON string.\n- `autoparse` (optional): Use the auto-parser algorithm to automatically extract data. Default is `false`.\n- `return_screenshot` (optional): Return a full-page screenshot of the target page. Default is `false`.\n- `resolve_captcha` (optional): Use a CAPTCHA solver integration to automatically solve interactive CAPTCHAs in the page. Default is `false`.\n\n#","ref":"ZenRows.Config.html#module-parameters"},{"type":"module","title":"Proxy countries - ZenRows.Config","doc":"List of some available countries and their code, you can check out the whole list on the [builder](https://app.zenrows.com/builder).\n\n- United States: us\n- Canada: ca\n- United Kingdom: gb\n- Germany: de\n- France: fr\n- Spain: es\n- Brazil: br\n- Mexico: mx\n- India: in\n- Japan: jp\n- China: cn","ref":"ZenRows.Config.html#module-proxy-countries"},{"type":"type","title":"ZenRows.Config.t/0","doc":"","ref":"ZenRows.Config.html#t:t/0"},{"type":"extras","title":"Zenrows","doc":"# Zenrows\n\nZenRows is an Elixir client library for interacting with the [ZenRows API](https://docs.zenrows.com/api-reference). It provides a simple and convenient way to send HTTP requests to the ZenRows API, allowing you to scrape web pages and extract data easily.\n\nView the [documentation](https://hexdocs.pm/zenrows/readme.html).","ref":"readme.html"},{"type":"extras","title":"Installation - Zenrows","doc":"Add zenrows to your list of dependencies in mix.exs:\n\n```elixir\ndef deps do\n  [\n    {:zenrows, \"~> 0.1\"}\n  ]\nend\n```\n\nThen run `mix deps.get` to install the dependency.","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Zenrows","doc":"Configure the zenrows library by adding the following to your `config.exs` file:\n\n```elixir\nconfig :zenrows,\n  api_key: \"YOUR_API_KEY\",\n  retries: 3,\n  timeout: 30_000\n```\n\n- `api_key` (required): Your ZenRows API key. Get your free API key from the ZenRows dashboard.\n- `adapter` (optional): The HTTP adapter module to use for requests. Default is `Tesla.Adapter.Hackney`.\n- `retries` (optional): The number of times to retry failed requests. Default is 3.\n- `timeout` (optional): The request timeout in milliseconds. Default is 30000.","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Zenrows","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Making GET requests - Zenrows","doc":"```elixir\nZenRows.get(\"https://example.com\", headers: %{\"Authorization\" => \"Bearer token\"}, config: %ZenRows.Config{js_render: true})\n```\n\n#","ref":"readme.html#making-get-requests"},{"type":"extras","title":"Making POST requests - Zenrows","doc":"```elixir\nZenRows.post(\"https://example.com\", data: %{key: \"value\"}, headers: %{\"Authorization\" => \"Bearer token\"})\n```","ref":"readme.html#making-post-requests"},{"type":"extras","title":"Request Options - Zenrows","doc":"- `:headers` (optional): A map of additional headers to include in the request. Default is an empty map.\n- `:config` (optional): A ZenRows.Config struct specifying the configuration options for the request. Default is an empty struct.\n- `:data` (optional): A map of data to be sent as the request body in a POST request. Default is an empty map.\n- `:retries` (optional): The number of times to retry failed requests. Overrides the application environment configuration.\n- `:timeout` (optional): The request timeout in milliseconds. Overrides the application environment configuration.\n\nFor more information on the available configuration options, refer to the `ZenRows.Config` [documentation](https://hexdocs.pm/zenrows/ZenRows.Config.html).","ref":"readme.html#request-options"},{"type":"extras","title":"Contributing - Zenrows","doc":"Contributions are welcome! If you find any issues or have suggestions for improvements, please open an issue or submit a pull request on the GitHub repository.","ref":"readme.html#contributing"},{"type":"extras","title":"License - Zenrows","doc":"ZenRows is released under the MIT License. See the [LICENSE](LICENSE) file for more information.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Strates LLC\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}